@@ -108,17 +108,11 @@ def main():
     uc.load_private(private_key)
     uc.load_public(public_key)
     uc.plugins = json.loads(
-        json.dumps(original["plugins"])
-            .replace("http://updates.jenkins-ci.org/download/plugins/", www_url + "/plugins/")
-            .replace("https://plugins.jenkins.io", www_url)
-            .replace("https://jenkins.io", www_url)
+        json.dumps(original["plugins"]).replace("https://updates.jenkins.io/download/plugins/", www_url + "/plugins/")
     )
     uc.warnings = original["warnings"]
     uc.core = json.loads(
-        json.dumps(original["core"])
-            .replace("http://updates.jenkins-ci.org/download/war/", www_url + "/war/")
-            .replace("https://plugins.jenkins.io", www_url)
-            .replace("https://jenkins.io", www_url)
+        json.dumps(original["core"]).replace("https://updates.jenkins.io/download/war/", www_url + "/war/")
     )
     with open(www_root + "/update-center.json", "w") as fd:
         uc.out(fd)
